Gridded Data
============


Gridded datasets in pyvista capture ``vtkRectilinearGrid`` and ``vtkImageData``
data objects on the VTK backend. These data types have common features which
are encompassed int their shared inheritance of :class:`pyvista.Grid`



.. rubric:: Attributes

.. autoautosummary:: pyvista.Grid
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.Grid
   :methods:

.. autoclass:: pyvista.Grid
   :show-inheritance:
   :members:
   :undoc-members:


Rectilinear Grid
----------------



.. rubric:: Attributes

.. autoautosummary:: pyvista.RectilinearGrid
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.RectilinearGrid
   :methods:

.. autoclass:: pyvista.RectilinearGrid
   :show-inheritance:
   :members:
   :undoc-members:



Uniform Grid
------------

PyVista's definition of a uniform grid is an extension of VTK's ``vtkImageData``


.. rubric:: Attributes

.. autoautosummary:: pyvista.UniformGrid
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.UniformGrid
   :methods:

.. autoclass:: pyvista.UniformGrid
   :show-inheritance:
   :members:
   :undoc-members:
